==> haskell-hslua-marshalling-2.3.1-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-marshalling.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-marshalling
version:              2.3.1
visibility:           public
id:                   hslua-marshalling-2.3.1-5wWczbqeVVIHyV9TxDKlQg
key:                  hslua-marshalling-2.3.1-5wWczbqeVVIHyV9TxDKlQg
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Marshalling of values between Haskell and Lua.
description:
    Provides functions to marshal values from Haskell
    to Lua, and /vice versa/.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  ef51561f0e2ce8d85ed0f4f517d0e03a
exposed:              True
exposed-modules:
    HsLua.Marshalling HsLua.Marshalling.Peek HsLua.Marshalling.Peekers
    HsLua.Marshalling.Push HsLua.Marshalling.Userdata

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-marshalling-2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-marshalling-2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-marshalling-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-marshalling
hs-libraries:         HShslua-marshalling-2.3.1-5wWczbqeVVIHyV9TxDKlQg
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hslua-core-2.3.1-GFEXISHm5zT41YgVZcMrDW mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-marshalling/html/hslua-marshalling.haddock

haddock-html:         /usr/share/doc/haskell-hslua-marshalling/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-marshalling-2.3.1-55-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-marshalling.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-marshalling
version:              2.3.1
visibility:           public
id:                   hslua-marshalling-2.3.1-8uxI8MIpn2t9Js23107Dyf
key:                  hslua-marshalling-2.3.1-8uxI8MIpn2t9Js23107Dyf
license:              MIT
copyright:
    © 2007–2012 Gracjan Polak;
    © 2012–2016 Ömer Sinan Ağacan;
    © 2017-2024 Albert Krewinkel

maintainer:           tarleb@hslua.org
author:               Albert Krewinkel, Gracjan Polak, Ömer Sinan Ağacan
homepage:             https://hslua.org/
synopsis:             Marshalling of values between Haskell and Lua.
description:
    Provides functions to marshal values from Haskell
    to Lua, and /vice versa/.

    This package is part of HsLua, a Haskell framework
    built around the embeddable scripting language
    <https://lua.org Lua>.

category:             Foreign
abi:                  a95d64db1d727e2510e24eb5a7ba2608
exposed:              True
exposed-modules:
    HsLua.Marshalling HsLua.Marshalling.Peek HsLua.Marshalling.Peekers
    HsLua.Marshalling.Push HsLua.Marshalling.Userdata

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hslua-marshalling-2.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hslua-marshalling-2.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hslua-marshalling-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-marshalling
hs-libraries:         HShslua-marshalling-2.3.1-8uxI8MIpn2t9Js23107Dyf
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    hslua-core-2.3.1-7STvIGdLdk7H2ZozH0ALPf mtl-2.2.2 text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-marshalling/html/hslua-marshalling.haddock

haddock-html:         /usr/share/doc/haskell-hslua-marshalling/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
